@@ -835,6 +835,8 @@ EvdevProc(DeviceIntPtr device, int what)
             xf86Msg(X_WARNING, "%s: Grab failed (%s)\n", pInfo->name,
                     strerror(errno));
         xf86AddEnabledDevice(pInfo);
+	if (pEvdev->flags & EVDEV_BUTTON_EVENTS)
+	    EvdevMBEmuPreInit(pInfo);
 	device->public.on = TRUE;
 	break;
 	    
@@ -1025,8 +1027,6 @@ EvdevPreInit(InputDriverPtr drv, IDevPtr dev, int flags)
      */
     pEvdev->tool = 1;
 
-    EvdevMBEmuPreInit(pInfo);
-
     device = xf86CheckStrOption(dev->commonOptions, "Path", NULL);
     if (!device)
 	device = xf86CheckStrOption(dev->commonOptions, "Device", NULL);
@@ -1052,6 +1052,7 @@ EvdevPreInit(InputDriverPtr drv, IDevPtr dev, int flags)
     /* parse the XKB options during kbd setup */
 
     if (EvdevProbe(pInfo)) {
+	close(pInfo->fd);
 	xf86DeleteInput(pInfo, 0);
         return NULL;
     }
